# Long-List

<p> I created this simple class because I faced a little problem with the maximum list size in python which is 536870912 (: </p>
<br/>
<p> So I created this object that creates an infinity long list </p>